@@ -29,7 +29,6 @@
 #include "ephy-settings.h"
 #include "ephy-shell.h"
 #include "ephy-state.h"
-#include "ephy-stock-icons.h"
 #include "ephy-string.h"
 #include "ephy-web-app-utils.h"
 
@@ -71,7 +70,7 @@ option_version_cb (const gchar *option_name,
                    gpointer     data,
                    GError     **error)
 {
-  g_print ("%s %s\n", _("GNOME Web Browser"), VERSION);
+  g_print ("%s %s\n", _("Web"), VERSION);
 
   exit (EXIT_SUCCESS);
   return FALSE;
@@ -206,7 +205,7 @@ show_error_message (GError **error)
                                    GTK_DIALOG_MODAL,
                                    GTK_MESSAGE_ERROR,
                                    GTK_BUTTONS_CLOSE,
-                                   _("Could not start GNOME Web Browser"));
+                                   _("Could not start Web"));
   gtk_message_dialog_format_secondary_text
     (GTK_MESSAGE_DIALOG (dialog),
      _("Startup failed because of the following error:\n%s"),
@@ -253,9 +252,6 @@ main (int argc,
   textdomain (GETTEXT_PACKAGE);
 #endif
 
-  /* Threads have to be initialised before calling ANY glib function */
-  g_thread_init (NULL);
-
   /* check libxml2 API version epiphany was compiled with against the
    * version we're running with.
    */
@@ -322,8 +318,8 @@ main (int argc,
 
   option_context = g_option_context_new ("");
   option_group = g_option_group_new ("epiphany",
-                                     N_("GNOME Web Browser"),
-                                     N_("GNOME Web Browser options"),
+                                     N_("Web"),
+                                     N_("Web options"),
                                      NULL, NULL);
 
   g_option_group_set_translation_domain (option_group, GETTEXT_PACKAGE);
@@ -383,6 +379,18 @@ main (int argc,
     exit (1);
   }
 
+  /* Work-around Flash Player crash */
+  g_setenv ("XLIB_SKIP_ARGB_VISUALS", "1", FALSE);
+
+  /* Start our services */
+  if (!ephy_file_helpers_init (profile_directory,
+                               private_instance || application_mode,
+                               keep_temp_directory || profile_directory,
+                               &error)) {
+    show_error_message (&error);
+    exit (1);
+  }
+
   arbitrary_url = g_settings_get_boolean (EPHY_SETTINGS_LOCKDOWN,
                                           EPHY_PREFS_LOCKDOWN_ARBITRARY_URL);
 
@@ -411,15 +419,6 @@ main (int argc,
 
   startup_error_quark = g_quark_from_static_string ("epiphany-startup-error");
 
-  /* Start our services */
-  if (!ephy_file_helpers_init (profile_directory,
-                               private_instance || application_mode,
-                               keep_temp_directory || profile_directory,
-                               &error)) {
-    show_error_message (&error);
-    exit (1);
-  }
-
   /* Delete the requested web application, if any. Must happen after
    * ephy_file_helpers_init (). */
   if (application_to_delete) {
@@ -427,21 +426,20 @@ main (int argc,
     exit (0);
   }
 
-  ephy_stock_icons_init ();
   ephy_file_load_accels ();
 
-  /* Work-around Flash Player crash */
-  g_setenv ("XLIB_SKIP_ARGB_VISUALS", "1", FALSE);
-
   /* Now create the shell */
   if (private_instance)
     mode = EPHY_EMBED_SHELL_MODE_PRIVATE;
   else if (application_mode) {
     char *app_name;
+    char *app_icon;
 
     mode = EPHY_EMBED_SHELL_MODE_APPLICATION;
 
     app_name = g_strrstr (profile_directory, EPHY_WEB_APP_PREFIX);
+    app_icon = g_build_filename (profile_directory, EPHY_WEB_APP_ICON_NAME, NULL);
+
     if (app_name) {
       /* Skip the 'app-' part */
       app_name += strlen (EPHY_WEB_APP_PREFIX);
@@ -449,16 +447,21 @@ main (int argc,
       g_set_prgname (app_name);
       g_set_application_name (app_name);
 
+      gtk_window_set_default_icon_from_file (app_icon, NULL);
+
       /* We need to re-set this because we have already parsed the
        * options, which inits GTK+ and sets this as a side effect. */
       gdk_set_program_class (app_name);
     }
+
+    g_free (app_icon);
   } else {
     mode = EPHY_EMBED_SHELL_MODE_BROWSER;
 
     g_set_prgname ("epiphany");
-    g_set_application_name (_("Web Browser"));
-    gtk_window_set_default_icon_name (EPHY_STOCK_EPHY);
+    g_set_application_name (_("Web"));
+
+    gtk_window_set_default_icon_name ("web-browser");
   }
 
   _ephy_shell_create_instance (mode);
